==> nextcloud-app-tasks-0.16.1-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/ia.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Importante",
    "Today" : "Hodie",
    "Week" : "Septimana",
    "All" : "Tote",
    "Current" : "Actual",
    "Completed" : "Completate",
    "Visibility of Smart Collections" : "Visibilitate de Collectiones Intelligente",
    "Hidden" : "Occultate",
    "Visible" : "Visibile",
    "Automatic" : "Automatic",
    "Share with users or groups" : "Compartir con usatores o gruppos",
    "Can edit" : "Can edit",
    "Edit" : "Modificar",
    "Export" : "Exportar",
    "Delete" : "Deler",
    "Unshare" : "Cessa de compartir",
    "An empty name is not allowed." : "Un nomine vacue non es permittite.",
    "Name" : "Nomine",
    "Deleted" : "Delite",
    "Restore" : "Restaurar",
    "Delete permanently" : "Deler permanentemente",
    "Cancel" : "Cancellar",
    "Close" : "Clauder",
    "Select tags to filter by" : "Selectionar etiquettas a filtrar per",
    "Change sort order" : "Cambiar ordine de classification",
    "Priority" : "Prioritate",
    "Alphabetically" : "Alphabeticamente",
    "Manually" : "Manualmente",
    "Tomorrow" : "Deman",
    "Details" : "Detalios",
    "Notes" : "Notas",
    "Reminders" : "Memento",
    "Repeat" : "Repeter",
    "When shared show full event" : "Quando compartite, monstrar evento integremente",
    "When shared show only busy" : "Quando compartite, monstrar solo si illo es occupate",
    "When shared hide this event" : "Quando compartite, celar iste evento",
    "Set start date" : "Assigna le data de initio",
    "Set due date" : "Assignar data debite"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-tasks-0.17.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/ia.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Importante",
    "Today" : "Hodie",
    "Week" : "Septimana",
    "All" : "Tote",
    "Current" : "Actual",
    "Completed" : "Completate",
    "Hidden" : "Occultate",
    "Visible" : "Visibile",
    "Automatic" : "Automatic",
    "Visibility of Smart Collections" : "Visibilitate de Collectiones Intelligente",
    "Share with users or groups" : "Compartir con usatores o gruppos",
    "Can edit" : "Can edit",
    "An empty name is not allowed." : "Un nomine vacue non es permittite.",
    "Edit" : "Modificar",
    "Export" : "Exportar",
    "Delete" : "Deler",
    "Unshare" : "Cessa de compartir",
    "Name" : "Nomine",
    "Deleted" : "Delite",
    "Restore" : "Restaurar",
    "Delete permanently" : "Deler permanentemente",
    "Cancel" : "Cancellar",
    "Go back" : "Retornar",
    "Close" : "Clauder",
    "Select tags to filter by" : "Selectionar etiquettas a filtrar per",
    "Priority" : "Prioritate",
    "Alphabetically" : "Alphabeticamente",
    "Tags" : "Etiquettas",
    "Manually" : "Manualmente",
    "Change sort order" : "Cambiar ordine de classification",
    "Tomorrow" : "Deman",
    "When shared show full event" : "Quando compartite, monstrar evento integremente",
    "When shared show only busy" : "Quando compartite, monstrar solo si illo es occupate",
    "When shared hide this event" : "Quando compartite, celar iste evento",
    "Set start date" : "Assigna le data de initio",
    "Set due date" : "Assignar data debite",
    "Details" : "Detalios",
    "Notes" : "Notas"
},
"nplurals=2; plural=(n != 1);");
